# eolearn.geometry subpackage

Geometry subpackage used for geometric transformation and conversion between vector and raster data.

For more information on the package content, visit [readthedocs](https://eo-learn.readthedocs.io/en/latest/eolearn.geometry.html).
